@@ -7,35 +7,30 @@ from pyroll.core.grooves import GrooveBase
 from pyroll.core.repr import ReprMixin
 from ..config import Config
 
+__all__ = ["GenericElongationGroove"]
+
 
 class GenericElongationGroove(GrooveBase, ReprMixin):
     """Represents a groove defined by the generic elongation groove geometry."""
 
     def __init__(
             self,
-
             r1: float,
             r2: float,
-
             flank_angle: Optional[float] = None,
             usable_width: Optional[float] = None,
             ground_width: Optional[float] = None,
             depth: Optional[float] = None,
-
             r3: float = 0,
             alpha3: float = 0,
-
             r4: float = 0,
             alpha4: float = 0,
-
             indent: float = 0,
             even_ground_width: float = 0,
-
             pad: float = 0,
             rel_pad: float = Config.GROOVE_PADDING,
             pad_angle: float = 0,
-
-            classifiers: Sequence[str] = ()
+            classifiers: Sequence[str] = (),
     ):
         """
         Give any three of ``usable_width``, ``ground_width``, ``flank_angle`` and ``depth``.
@@ -66,8 +61,20 @@ class GenericElongationGroove(GrooveBase, ReprMixin):
         :param classifiers: sequence of additional type classifiers
         """
 
-        mandatory_positive_or_zero = [r1, r2, r3, r4, alpha3, alpha4, indent, even_ground_width, flank_angle,
-                                      usable_width, ground_width, depth]
+        mandatory_positive_or_zero = [
+            r1,
+            r2,
+            r3,
+            r4,
+            alpha3,
+            alpha4,
+            indent,
+            even_ground_width,
+            flank_angle,
+            usable_width,
+            ground_width,
+            depth,
+        ]
         if not all(value is None or value >= 0 for value in mandatory_positive_or_zero):
             raise ValueError("Groove arguments have to be non-negative.")
 
@@ -193,22 +200,22 @@ class GenericElongationGroove(GrooveBase, ReprMixin):
         yield self.z0, self.y0
 
         if not np.isclose(self.z1, self.z3):
-            for z in np.linspace(self.z1, self.z3, 20, endpoint=False):
+            for z in np.linspace(self.z1, self.z3, Config.GROOVE_RADIUS_POINT_COUNT, endpoint=False):
                 yield z, self._r1_contour_line(z)
 
         if not np.isclose(self.z3, self.z4):
             yield self.z3, self.y3
 
         if not np.isclose(self.z4, self.z5):
-            for z in np.linspace(self.z4, self.z5, 20, endpoint=False):
+            for z in np.linspace(self.z4, self.z5, Config.GROOVE_RADIUS_POINT_COUNT, endpoint=False):
                 yield z, self._r2_contour_line(z)
 
         if not np.isclose(self.z5, self.z6):
-            for z in np.linspace(self.z5, self.z6, 20, endpoint=False):
+            for z in np.linspace(self.z5, self.z6, Config.GROOVE_RADIUS_POINT_COUNT, endpoint=False):
                 yield z, self._r3_contour_line(z)
 
         if not np.isclose(self.z6, self.z7):
-            for z in np.linspace(self.z6, self.z7, 20, endpoint=False):
+            for z in np.linspace(self.z6, self.z7, Config.GROOVE_RADIUS_POINT_COUNT, endpoint=False):
                 yield z, self._r4_contour_line(z)
 
         yield self.z9, self.y9
@@ -225,15 +232,32 @@ class GenericElongationGroove(GrooveBase, ReprMixin):
     def cross_section(self) -> Polygon:
         return self._cross_section
 
+    @property
+    def groove_factor(self) -> float:
+        return self.contour_line.centroid.y
+
     def local_depth(self, z) -> Union[float, np.ndarray]:
         z = np.abs(z)
 
         return np.piecewise(
             z,
-            [z < self.z7, (self.z7 <= z) & (z < self.z6), (self.z6 <= z) & (z < self.z5),
-             (self.z5 <= z) & (z < self.z4), (self.z4 <= z) & (z < self.z3), (self.z3 <= z) & (z < self.z1)],
-            [self._ground_contour_line, self._r4_contour_line, self._r3_contour_line, self._r2_contour_line,
-             self._flank_contour_line, self._r1_contour_line, self._face_contour_line]
+            [
+                z < self.z7,
+                (self.z7 <= z) & (z < self.z6),
+                (self.z6 <= z) & (z < self.z5),
+                (self.z5 <= z) & (z < self.z4),
+                (self.z4 <= z) & (z < self.z3),
+                (self.z3 <= z) & (z < self.z1),
+            ],
+            [
+                self._ground_contour_line,
+                self._r4_contour_line,
+                self._r3_contour_line,
+                self._r2_contour_line,
+                self._flank_contour_line,
+                self._r1_contour_line,
+                self._face_contour_line,
+            ],
         )
 
     @property
@@ -266,9 +290,25 @@ class GenericElongationGroove(GrooveBase, ReprMixin):
     @property
     def __attrs__(self):
         return {
-            n: v for n in ["r1", "r2", "r3", "r4", "alpha1", "alpha2", "alpha3", "alpha4", "depth", "indent",
-                           "even_ground_width", "usable_width", "classifiers", "flank_angle", "pad_angle",
-                           "ground_width",
-                           "contour_line"]
+            n: v
+            for n in [
+                "r1",
+                "r2",
+                "r3",
+                "r4",
+                "alpha1",
+                "alpha2",
+                "alpha3",
+                "alpha4",
+                "depth",
+                "indent",
+                "even_ground_width",
+                "usable_width",
+                "classifiers",
+                "flank_angle",
+                "pad_angle",
+                "ground_width",
+                "contour_line",
+            ]
             if (v := getattr(self, n))
         }
