@@ -1,4 +1,4 @@
-from typing import Union, Set
+from typing import Union, Set, List
 
 import numpy as np
 from scipy.interpolate import interpn
@@ -7,13 +7,22 @@ from shapely.geometry import LineString
 from ..grooves import GrooveBase
 from ..hooks import HookHost, Hook
 
+__all__ = ["Roll"]
+
 
 class Roll(HookHost):
     """Represents a roll."""
 
+    material = Hook[Union[str, Set[str]]]()
+    """String or sequence of strings classifying the material of the roll.
+    Can be used by material databases to retrieve respective data."""
+
     nominal_radius = Hook[float]()
     """Nominal radius."""
 
+    nominal_diameter = Hook[float]()
+    """Nominal diameter."""
+
     working_radius = Hook[float]()
     """Effective working radius (equivalent flat rolling)."""
 
@@ -29,6 +38,9 @@ class Roll(HookHost):
     surface_velocity = Hook[float]()
     """Tangential velocity of the outer roll surface (at nominal radius)."""
 
+    working_velocity = Hook[float]()
+    """Tangential velocity of the roll surface (at working radius)."""
+
     contour_points = Hook[LineString]()
     """Points of the contour line in the z-y-plane."""
 
@@ -89,13 +101,16 @@ class Roll(HookHost):
 
     surface_y = Hook[np.ndarray]()
     """
-    Y-Values of the surface interpolation grid. Array of shape (n, m), 
+    Y-Values of the surface interpolation grid. Array of shape (n, m),
     where ``n = len(self.surface_x)`` and ``m = len(self.surface_z)``.
     """
 
     heat_penetration_number = Hook[float]()
     """Mean heat penetration number of the roll material."""
 
+    coefficient_of_thermal_expansion = Hook[float]()
+    """Coefficient of thermal expansion of the roll material."""
+
     thermal_diffusivity = Hook[float]()
     """Mean thermal diffusivity of the roll material."""
 
@@ -105,23 +120,22 @@ class Roll(HookHost):
     neutral_point = Hook[float]()
     """Point at the roll surface where the shear stress is zero."""
 
-    thermal_stress = Hook[float]()
-    """Thermal stress inside the roll body."""
+    contact_duration = Hook[float]()
+    """Time a surface point of the roll is in contact with the material surface."""
 
-    centrifugal_force_stress = Hook[float]()
-    """Centrifugal stress inside the roll body."""
+    idle_duration = Hook[float]()
+    """Time the roll is not in """
 
-    mounting_stress = Hook[float]()
-    """Stress inside the roll body caused by the roll mounting system."""
+    peclet_number = Hook[float]()
+    """Peclet number."""
 
-    ultimate_tensile_strength = Hook[float]()
-    """Ultimate Tensile strength of the roll material."""
+    temperature_field = Hook[List[np.ndarray[float]]]()
+    """Temperature field inside the roll body."""
 
-    def __init__(
-            self,
-            groove: GrooveBase,
-            **kwargs
-    ):
+    thermal_stress_field = Hook[List[np.ndarray[float]]]()
+    """Thermal stress field inside the roll body."""
+
+    def __init__(self, groove: GrooveBase, **kwargs):
         """
         :param groove: the groove object defining the shape of the roll's surface
         :param kwargs: additional hook values as keyword arguments to set explicitly
