@@ -1,5 +1,11 @@
+import numpy as np
+
 from ..unit import Unit
 from ..hooks import Hook
+from shapely.geometry import MultiLineString
+from typing import List
+
+__all__ = ["DeformationUnit"]
 
 
 class DeformationUnit(Unit):
@@ -54,9 +60,36 @@ class DeformationUnit(Unit):
     deformation_resistance = Hook[float]()
     """Equivalent deformation resistance (mean flow stress increased by deformation efficiency)."""
 
+    contact_pressure = Hook[float]()
+    """Pressure acting on the contact area."""
+
+    contact_friction = Hook[float]()
+    """Friction stress acting on the contact area."""
+
+    zener_holomon_parameter = Hook[float]()
+    """Temperature corrected strain rate acc. to Zener and Holomon."""
+
     class Profile(Unit.Profile):
         """Represents a profile in context of a deformation unit."""
 
+        contact_lines = Hook[MultiLineString]()
+        """List of lines that are in contact with tooling (rolls)."""
+
+        contact_angles = Hook[List[np.ndarray]]()
+        """List of contour angles that are in contact with tooling (rolls)."""
+
+        free_surface_lines = Hook[MultiLineString]()
+        """List of lines that are not in contact with tooling (rolls)."""
+
+        contact_width = Hook[float]()
+        """Projected width of contact lines."""
+
+        contact_depth = Hook[float]()
+        """Projected depth of contact lines."""
+
+        longitudinal_angle = Hook[float]()
+        """Longitudinal angle between the deformation unit and the workpiece."""
+
     class InProfile(Profile, Unit.InProfile):
         """Represents an incoming profile of a deformation unit."""
 
