@@ -1,6 +1,9 @@
 import numpy as np
 
-from ..roll_pass import DeformationUnit
+from shapely.geometry import LineString
+
+from ..deformation_unit import DeformationUnit
+from ...config import Config
 
 
 @DeformationUnit.draught
@@ -65,7 +68,7 @@ def rel_elongation(self: DeformationUnit):
 
 @DeformationUnit.strain
 def strain(self: DeformationUnit):
-    return np.sqrt(2 / 3 * (self.log_elongation ** 2 + self.log_spread ** 2 + self.log_draught ** 2))
+    return np.sqrt(2 / 3 * (self.log_elongation**2 + self.log_spread**2 + self.log_draught**2))
 
 
 @DeformationUnit.strain_rate
@@ -76,3 +79,24 @@ def strain_rate(self: DeformationUnit):
 @DeformationUnit.free_surface_area
 def free_surface_area(self: DeformationUnit):
     return self.surface_area - self.contact_area
+
+
+@DeformationUnit.zener_holomon_parameter
+def zener_holomon_parameter(self: DeformationUnit):
+    return self.strain_rate * np.exp(
+        self.in_profile.deformation_activation_energy / (Config.UNIVERSAL_GAS_CONSTANT * self.in_profile.temperature)
+    )
+
+
+@DeformationUnit.Profile.contact_angles
+def contact_contour_angles(self: DeformationUnit.Profile):
+    def calculate_angles(contour_line: LineString):
+        x, y = np.array(contour_line.coords.xy)
+
+        xdiff = x[2:] - x[:-2]
+        ydiff = y[2:] - y[:-2]
+        angles = np.arctan2(ydiff, xdiff)
+
+        return angles
+
+    return [calculate_angles(line) for line in self.contact_lines.geoms]
